#include "lua.hpp"

#include "ConfigLoader.h"
#include "GameManager.h"
#include "Path.h"

ConfigLoader::ConfigLoader()
{
  pL = lua_open(); 
}

ConfigLoader::~ConfigLoader()
{
  lua_close(pL);
}

void ConfigLoader::load(std::string filename)
{
  filename = GameManager::getSingletonPtr()->getPath()->find(filename);
  assert(filename != "");

  printf("load file %s\n", filename.c_str());

  int ret = luaL_loadfile(pL, filename.c_str());
  assert(ret == 0);

  int status = lua_pcall(pL, 0, 0, 0);
  assert(status == 0);
} 

bool ConfigLoader::pGetGlobal(std::string name)
{
  printf("loading from lua : %s\n", name.c_str());
  lua_getglobal(pL, name.c_str());

  bool ret = lua_isnil(pL, -1);
  assert(!ret);

  return ret;
}

std::string ConfigLoader::getString(std::string name)
{
  pGetGlobal(name.c_str());

  const char* chr = lua_tostring(pL, -1);

  return std::string(chr);
}

int ConfigLoader::getInt(std::string name)
{
  pGetGlobal(name.c_str());

  return lua_tointeger(pL, -1);
}

double ConfigLoader::getDouble(std::string name)
{
  pGetGlobal(name.c_str());

  return lua_tonumber(pL, -1);
}

bool ConfigLoader::getBoolean(std::string name)
{
  pGetGlobal(name.c_str());

  return lua_toboolean(pL, -1);
}

float ConfigLoader::getFloat(std::string name)
{
	return (float) getDouble(name);
}

void ConfigLoader::_printEach()
{
  lua_pushnil(pL);
  while(lua_next(pL, LUA_GLOBALSINDEX) != 0)
  {
    printf("%s - %s\n", lua_tostring(pL, -2), lua_typename(pL, lua_type(pL, -1)));
    lua_pop(pL, 1);
  }
}

